nixy_markdown_controller library

Nixy markdown controller

Classes

NixyTextFieldController
The NixyTextFieldController class is a custom implementation of the TextEditingController in Dart that supports various text patterns and styles, including URLs, checkboxes, and code blocks.

Enums

Patterns

Constants

BOLD_TEXT_STYLE → const TextStyle
CODE_STYLE → const TextStyle
URL_STYLE → const TextStyle

Properties

CHECKBOX_LIST_STYLE TextStyle
final
HEADERS_STYLE TextStyle
final