match property

String match
final

final String match; is declaring a final variable match of type String. This variable is used to store the specific text that was matched by the pattern in the text editing value. It is used in the onPressUrlPattern(), onPressCheckboxListPattern(), and onPressCheckboxDoneListPattern() methods to manipulate the text in the text editing value based on the matched pattern.

Implementation

final String match;