TapRecognizers class
The TapRecognizers class provides methods for recognizing and handling tap gestures on specific patterns in text editing values.
Constructors
- TapRecognizers({required Patterns patternMatched, required String match, required BuildContext context})
- The TapRecognizers class provides methods for recognizing and handling tap gestures on specific patterns in text editing values.
Properties
- context → BuildContext
-
Build context for showing alerts.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- match → String
-
final String match;is declaring a final variablematchof typeString. This variable is used to store the specific text that was matched by the pattern in the text editing value. It is used in theonPressUrlPattern(),onPressCheckboxListPattern(), andonPressCheckboxDoneListPattern()methods to manipulate the text in the text editing value based on the matched pattern.final - patternMatched → Patterns
-
final Patterns patternMatched;is declaring a final variablepatternMatchedof typePatterns. This variable is used to store the pattern that was matched in the text editing value.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onPressCheckboxDoneListPattern(
TextEditingValue value, String text, void onUpdateValue(TextEditingValue newValue)) → TapGestureRecognizer - This function returns a TapGestureRecognizer that updates a given TextEditingValue with a new text value that replaces a specific pattern with a checkbox.
-
onPressCheckboxListPattern(
TextEditingValue value, String text, void onUpdateValue(TextEditingValue newValue)) → TapGestureRecognizer - This function returns a TapGestureRecognizer that updates a given TextEditingValue with a new text value that replaces a specific pattern with a checkbox.
-
onPressUrlPattern(
) → TapGestureRecognizer - This function returns a TapGestureRecognizer that launches a URL if it matches a specified pattern.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited